==> pcv-1.0.0.tar.gz: pcv/src/Form/AdminPasswordValidator.php <==
<?php

namespace Drupal\pcv\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\user\Entity\Role;

/**
 * LanguageConverter Admin Form.
 */
class AdminPasswordValidator extends ConfigFormBase {

  /**
   * Settings Config Variable.
   *
   * @var DrupalSettings
   */
  protected $settings;

  /**
   * {@inheritdoc}
   */
  public function __construct() {
    $this->settings = 'pcv.settings';
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'pcv_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      $this->settings,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $roleMultiple = Role::loadMultiple();
    $roles = [];
    foreach ($roleMultiple as $key => $role) {
      if ($key == 'anonymous' || $key == 'authenticated') {
        continue;
      }
      $roles[$key] = $role->label();
    }
    $form = parent::buildForm($form, $form_state);
    $config = $this->config($this->settings);
    $form['roles'] = [
      '#type' => 'fieldset',
      '#title' => t('Roles'),
      '#description' => t('Roles that can overwride this rules.'),
    ];
    $form['roles']['exclude'] = [
      '#type' => 'checkboxes',
      '#title' => t('Roles Overwride'),
      '#options' => $roles,
      '#default_value' => $config->get('roles_overwrite'),
    ];
    $form['character'] = [
      '#type' => 'fieldset',
      '#title' => t('Character group'),
    ];
    $form['character']['character_enable'] = [
      '#type' => 'checkbox',
      '#title' => 'Enable',
      '#default_value' => $config->get('character_enable')
    ];
    $form['character']['character_text'] = [
      '#type' => 'textfield',
      '#title' => 'Character limit text',
      '#default_value' => $config->get('character_text')
    ];
    $form['character']['character_limit'] = [
      '#type' => 'number',
      '#title' => 'Character limit',
      '#default_value' => $config->get('character_limit')
    ];
    $form['lowercase'] = [
      '#type' => 'fieldset',
      '#title' => 'LowerCase group',
    ];
    $form['lowercase']['lowercase_enable'] = [
      '#type' => 'checkbox',
      '#title' => 'Enable',
      '#default_value' => $config->get('lowercase_enable')
    ];
    $form['lowercase']['lowercase_text'] = [
      '#type' => 'textfield',
      '#title' => 'Lowercase letters text',
      '#default_value' => $config->get('lowercase_text')
    ];
    $form['uppercase'] = [
      '#type' => 'fieldset',
      '#title' => 'UpperCase group',
    ];
    $form['uppercase']['uppercase_enable'] = [
      '#type' => 'checkbox',
      '#title' => 'Enable',
      '#default_value' => $config->get('uppercase_enable')
    ];
    $form['uppercase']['uppercase_text'] = [
      '#type' => 'textfield',
      '#title' => 'UpperCase letters text',
      '#default_value' => $config->get('uppercase_text')
    ];
    $form['number'] = [
      '#type' => 'fieldset',
      '#title' => 'Numbers group',
    ];
    $form['number']['number_enable'] = [
      '#type' => 'checkbox',
      '#title' => 'Enable',
      '#default_value' => $config->get('number_enable')
    ];
    $form['number']['number_text'] = [
      '#type' => 'textfield',
      '#title' => 'Number text',
      '#default_value' => $config->get('number_text')
    ];
    $form['punctuation'] = [
      '#type' => 'fieldset',
      '#title' => 'Puntuation group',
    ];
    $form['punctuation']['punctuation_enable'] = [
      '#type' => 'checkbox',
      '#title' => 'Enable',
      '#default_value' => $config->get('punctuation_enable')
    ];
    $form['punctuation']['punctuation_text'] = [
      '#type' => 'textfield',
      '#title' => 'Puntiation text',
      '#default_value' => $config->get('punctuation_text')
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->config($this->settings)
      ->set('roles_overwrite', $values['exclude'])
      ->set('character_enable', $values['character_enable'])
      ->set('character_text', $values['character_text'])
      ->set('character_limit', $values['character_limit'])
      ->set('lowercase_enable', $values['lowercase_enable'])
      ->set('lowercase_text', $values['lowercase_text'])
      ->set('uppercase_enable', $values['uppercase_enable'])
      ->set('uppercase_text', $values['uppercase_text'])
      ->set('number_enable', $values['number_enable'])
      ->set('number_text', $values['number_text'])
      ->set('punctuation_enable', $values['punctuation_enable'])
      ->set('punctuation_text', $values['punctuation_text'])
      ->save();
    return parent::submitForm($form, $form_state);
  }

}

==> pcv-1.0.2.tar.gz: pcv/src/Form/AdminPasswordValidator.php <==
<?php

namespace Drupal\pcv\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\user\Entity\Role;

/**
 * LanguageConverter Admin Form.
 */
class AdminPasswordValidator extends ConfigFormBase {

  /**
   * Settings Config Variable.
   *
   * @var DrupalSettings
   */
  protected $settings;

  /**
   * {@inheritdoc}
   */
  public function __construct() {
    $this->settings = 'pcv.settings';
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'pcv_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      $this->settings,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $roleMultiple = Role::loadMultiple();
    $roles = [];
    foreach ($roleMultiple as $key => $role) {
      if ($key == 'anonymous' || $key == 'authenticated') {
        continue;
      }
      $roles[$key] = $role->label();
    }
    $form = parent::buildForm($form, $form_state);
    $config = $this->config($this->settings);
    $form['roles'] = [
      '#type' => 'fieldset',
      '#title' => t('Roles'),
      '#description' => t('Roles that can override this rules.'),
    ];
    $form['roles']['exclude'] = [
      '#type' => 'checkboxes',
      '#title' => t('Roles Override'),
      '#options' => $roles,
      '#default_value' => $config->get('roles_overwrite'),
    ];
    $form['character'] = [
      '#type' => 'fieldset',
      '#title' => t('Character group'),
    ];
    $form['character']['character_enable'] = [
      '#type' => 'checkbox',
      '#title' => 'Enable',
      '#default_value' => $config->get('character_enable')
    ];
    $form['character']['character_text'] = [
      '#type' => 'textfield',
      '#title' => 'Character limit text',
      '#default_value' => $config->get('character_text')
    ];
    $form['character']['character_limit'] = [
      '#type' => 'number',
      '#title' => 'Character limit',
      '#default_value' => $config->get('character_limit')
    ];
    $form['lowercase'] = [
      '#type' => 'fieldset',
      '#title' => 'LowerCase group',
    ];
    $form['lowercase']['lowercase_enable'] = [
      '#type' => 'checkbox',
      '#title' => 'Enable',
      '#default_value' => $config->get('lowercase_enable')
    ];
    $form['lowercase']['lowercase_text'] = [
      '#type' => 'textfield',
      '#title' => 'Lowercase letters text',
      '#default_value' => $config->get('lowercase_text')
    ];
    $form['uppercase'] = [
      '#type' => 'fieldset',
      '#title' => 'UpperCase group',
    ];
    $form['uppercase']['uppercase_enable'] = [
      '#type' => 'checkbox',
      '#title' => 'Enable',
      '#default_value' => $config->get('uppercase_enable')
    ];
    $form['uppercase']['uppercase_text'] = [
      '#type' => 'textfield',
      '#title' => 'UpperCase letters text',
      '#default_value' => $config->get('uppercase_text')
    ];
    $form['number'] = [
      '#type' => 'fieldset',
      '#title' => 'Numbers group',
    ];
    $form['number']['number_enable'] = [
      '#type' => 'checkbox',
      '#title' => 'Enable',
      '#default_value' => $config->get('number_enable')
    ];
    $form['number']['number_text'] = [
      '#type' => 'textfield',
      '#title' => 'Number text',
      '#default_value' => $config->get('number_text')
    ];
    $form['punctuation'] = [
      '#type' => 'fieldset',
      '#title' => 'Puntuation group',
    ];
    $form['punctuation']['punctuation_enable'] = [
      '#type' => 'checkbox',
      '#title' => 'Enable',
      '#default_value' => $config->get('punctuation_enable')
    ];
    $form['punctuation']['punctuation_text'] = [
      '#type' => 'textfield',
      '#title' => 'Puntiation text',
      '#default_value' => $config->get('punctuation_text')
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->config($this->settings)
      ->set('roles_overwrite', $values['exclude'])
      ->set('character_enable', $values['character_enable'])
      ->set('character_text', $values['character_text'])
      ->set('character_limit', $values['character_limit'])
      ->set('lowercase_enable', $values['lowercase_enable'])
      ->set('lowercase_text', $values['lowercase_text'])
      ->set('uppercase_enable', $values['uppercase_enable'])
      ->set('uppercase_text', $values['uppercase_text'])
      ->set('number_enable', $values['number_enable'])
      ->set('number_text', $values['number_text'])
      ->set('punctuation_enable', $values['punctuation_enable'])
      ->set('punctuation_text', $values['punctuation_text'])
      ->save();
    return parent::submitForm($form, $form_state);
  }

}
